<?php
// $Id: custom_search.admin.inc,v 1.1.4.1 2010/03/04 10:34:13 jdanthinne Exp $

/**
 * @file
 * Admin settings for custom search
 */

/**
 * Implements hook_help().
 */
function custom_search_help($path, $arg) {
  switch ($path) {
    case 'admin/config/search/custom_search/content':
      return t('Select the search types to present as search options in the search block. If none is selected, no selector will be displayed.');
      break;
    case 'admin/config/search/custom_search/taxonomy':
      return t('Select the vocabularies to present as search options in the search block. If none is selected, no selector will be displayed.');
      break;
  }
}

/**
 * General settings.
 */
function custom_search_admin() {
  // Labels & default text.
  $form['search_box'] = array(
    '#type'         => 'fieldset',
    '#title'        => t('Search box'),
  );
  $form['search_box']['custom_search_label_visibility'] = array(
    '#type'           => 'checkbox',
    '#title'          => t('Display label'),
    '#default_value'  => variable_get('custom_search_label_visibility', TRUE),
  );
  $form['search_box']['custom_search_label'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Search box label'),
    '#default_value'  => variable_get('custom_search_label', CUSTOM_SEARCH_LABEL_DEFAULT),
    '#description'    => t('Enter the label text for the search box. The default value is "!default".', array('!default' => CUSTOM_SEARCH_LABEL_DEFAULT)),
  );
  $form['search_box']['custom_search_text'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Search box default text'),
    '#default_value'  => variable_get('custom_search_text', ''),
    '#description'    => t('This will change the default text inside the search form. Leave blank for no text. This field is blank by default.'),
  );

  // Submit button.
  $form['submit_button'] = array(
    '#type'         => 'fieldset',
    '#title'        => t('Submit button'),
  );
  $form['submit_button']['custom_search_submit_text'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Submit button text'),
    '#default_value'  => variable_get('custom_search_submit_text', CUSTOM_SEARCH_SUBMIT_TEXT_DEFAULT),
    '#description'    => t('Enter the text for the submit button. Leave blank to hide it. The default value is "!default".', array('!default' => CUSTOM_SEARCH_SUBMIT_TEXT_DEFAULT)),
  );
  $form['submit_button']['custom_search_image_path'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Submit image path'),
    '#description'    => t('The path to the file you would like to use as submit button instead of the default text button.'),
    '#default_value'  => variable_get('custom_search_image_path', ''),
  );
  $form['submit_button']['custom_search_image'] = array(
    '#type'           => 'file',
    '#title'          => t('Submit image'),
    '#description'    => t('If you don\'t have direct file access to the server, use this field to upload your image.'),
  );

  // Ordering.
  $form['order'] = array(
    '#type'         => 'fieldset',
    '#title'        => t('Elements ordering'),
  );
  $form['order']['custom_search_order'] = array(
    '#tree'   => TRUE,
    '#theme'  => 'custom_search_sort_form',
  );
  $form['order']['custom_search_order']['search_box'] = array(
    '#title'  => t('Search Box'),
    'sort'    => array('#type' => 'weight', '#default_value' => variable_get('custom_search_search_box_weight', -1)),
    '#weight' => variable_get('custom_search_search_box_weight', -1),
  );
  if (count(array_filter(array_merge(variable_get('custom_search_node_types', array()), variable_get('custom_search_other', array()))))) {
    $form['order']['custom_search_order']['content_types'] = array(
      '#title'  => t('Content Types'),
      'sort'    => array('#type' => 'weight', '#default_value' => variable_get('custom_search_content_types_weight', 0)),
      '#weight' => variable_get('custom_search_content_types_weight', 0),
    );
  }
  if (module_exists('taxonomy')) {
    $vocabularies = taxonomy_get_vocabularies();
    $w = 1;
    foreach ($vocabularies as $voc) {
      if (variable_get('custom_search_voc' . $voc->vid . '_selector', 'disabled') != 'disabled') {
        $form['order']['custom_search_order']['taxonomy' . $voc->vid] = array(
          '#title'  => t('Taxonomy') . ': ' . $voc->name,
          'sort'    => array('#type' => 'weight', '#default_value' => variable_get('custom_search_taxonomy' . $voc->vid . '_weight', $w)),
          '#weight' => variable_get('custom_search_taxonomy' . $voc->vid . '_weight', $w),
        );
        $w++;
      }
    }
  }
  $form['order']['custom_search_order']['submit_button'] = array(
    '#title'  => t('Submit button'),
    'sort'    => array('#type' => 'weight', '#default_value' => variable_get('custom_search_submit_button_weight', 10)),
    '#weight' => variable_get('custom_search_submit_button_weight', 10),
  );

  $form['#attributes'] = array('enctype' => 'multipart/form-data');
  $form['#submit'][] = 'custom_search_admin_submit';
  return system_settings_form($form);
}

/**
 * Submit callback.
 */
function custom_search_admin_submit($form, &$form_state) {
  // Saves the ordering.
  foreach ($form_state['values']['custom_search_order'] as $key => $data) {
    variable_set('custom_search_' . $key . '_weight', $data['sort']);
  }

  // Uploads an image.
  $directory_path = 'public://custom_search';
  file_prepare_directory($directory_path, FILE_CREATE_DIRECTORY);
  // Check for a new uploaded image.
  if ($file = file_save_upload('custom_search_image', array('file_validate_is_image' => array()))) {
    if ($filepath = file_unmanaged_copy($file->uri, $directory_path)) {
      $form_state['values']['custom_search_image_path'] = $filepath;
    }
  }
}

/**
 * Theme the re-ordering form.
 */
function theme_custom_search_sort_form($form) {
  $form = $form['form'];
  drupal_add_tabledrag('custom-search-sort', 'order', 'sibling', 'sort');
  $header = array(t('Elements'), 'sort');
  foreach (element_children($form) as $key) {
    // Add class to group weight fields for drag and drop.
    $form[$key]['sort']['#attributes']['class'] = array('sort');
    $row = array();
    $row[] = $form[$key]['#title'];
    $row[] = drupal_render($form[$key]['sort']);
    $rows[] = array('data' => $row, 'class' => array('draggable'));
  }
  $output = theme('table', array('header' => $header, 'rows' => $rows, 'attributes' => array('id' => 'custom-search-sort')));
  $output .= drupal_render_children($form);
  return $output;
}

/**
 * Content settings.
 */
function custom_search_content_admin() {
  $form['custom_search_node_types'] = array(
    '#type'           => 'checkboxes',
    '#title'          => t('Content types'),
    '#default_value'  => variable_get('custom_search_node_types', array()),
    '#options'        => node_type_get_names(),
  );
  // Other searches.
  $options = array();
  foreach (module_implements('search_info') as $module) {
    if ($module != 'node' && $name = module_invoke($module, 'search_info')) {
      $options[$module] = $name['title'];
    }
  }
  if (count($options)) {
    $form['custom_search_other'] = array(
      '#type'           => 'checkboxes',
      '#title'          => t('Other searches'),
      '#default_value'  => variable_get('custom_search_other', array()),
      '#options'        => $options,
    );
  }
  $form['custom_search_type_selector'] = array(
    '#type'           => 'select',
    '#title'          => t('Selector type'),
    '#options'        => array(
      'select'      => t('Drop-down list'),
      'radios'      => t('Radio buttons'),
      'checkboxes'  => t('Checkboxes'),
    ),
    '#description'    => t('Choose which selector type to use. Only checkboxes can select multipe choices. Note: content types and other searches cannot be combined in a single search.'),
    '#default_value'  => variable_get('custom_search_type_selector', 'select'),
  );
  $form['custom_search_type_selector_label_visibility'] = array(
    '#type'           => 'checkbox',
    '#title'          => t('Display label'),
    '#default_value'  => variable_get('custom_search_type_selector_label_visibility', TRUE),
  );
  $form['custom_search_type_selector_label'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Label text'),
    '#default_value'  => variable_get('custom_search_type_selector_label', CUSTOM_SEARCH_TYPE_SELECTOR_LABEL_DEFAULT),
    '#description'    => t('Enter the label text for the selector. The default value is "!default".', array('!default' => CUSTOM_SEARCH_TYPE_SELECTOR_LABEL_DEFAULT)),
  );
  $form['custom_search_type_selector_all'] = array(
    '#type'           => 'textfield',
    '#title'          => t('-Any content type- text'),
    '#default_value'  => variable_get('custom_search_type_selector_all', CUSTOM_SEARCH_ALL_TEXT_DEFAULT),
    '#required'       => TRUE,
    '#description'    => t('Enter the text for "any content type" choice. The default value is "!default".', array('!default' => CUSTOM_SEARCH_ALL_TEXT_DEFAULT)),
  );

  return system_settings_form($form);
}

/**
 * Taxonomy settings.
 */
function custom_search_taxonomy_admin() {
  $vocabularies = taxonomy_get_vocabularies();
  if (count($vocabularies)) {
    $options = array();
    foreach ($vocabularies as $voc) {
      $form[$voc->name] = array(
        '#type'         => 'fieldset',
        '#title'        => $voc->name,
        '#collapsible'  => TRUE,
        '#collapsed'    => (variable_get('custom_search_voc' . $voc->vid . '_selector', 'disabled') == 'disabled') ? TRUE : FALSE,
      );
      $form[$voc->name]['custom_search_voc' . $voc->vid . '_selector'] = array(
        '#type'           => 'select',
        '#title'          => t('Selector type'),
        '#options'        => array(
          'disabled'    => t('Disabled'),
          'select'      => t('Drop-down list'),
          'radios'      => t('Radio buttons'),
          'checkboxes'  => t('Checkboxes'),
        ),
        '#description'    => t('Choose which selector type to use. Only checkboxes can select multipe choices.'),
        '#default_value'  => variable_get('custom_search_voc' . $voc->vid . '_selector', 'disabled'),
      );
      $form[$voc->name]['custom_search_voc' . $voc->vid . '_selector_label_visibility'] = array(
        '#type'           => 'checkbox',
        '#title'          => t('Display label'),
        '#default_value'  => variable_get('custom_search_voc' . $voc->vid . '_selector_label_visibility', TRUE),
      );
      $form[$voc->name]['custom_search_voc' . $voc->vid . '_selector_label'] = array(
        '#type'           => 'textfield',
        '#title'          => t('Label text'),
        '#default_value'  => variable_get('custom_search_voc' . $voc->vid . '_selector_label', $voc->name),
        '#description'    => t('Enter the label text for the selector. The default value is "!default".', array('!default' => $voc->name)),
      );
      $form[$voc->name]['custom_search_voc' . $voc->vid . '_selector_all'] = array(
        '#type'           => 'textfield',
        '#title'          => t('-Any- text'),
        '#default_value'  => variable_get('custom_search_voc' . $voc->vid . '_selector_all', CUSTOM_SEARCH_ALL_TEXT_DEFAULT),
        '#required'       => TRUE,
        '#description'    => t('Enter the text for "any term" choice. The default value is "!default".', array('!default' => CUSTOM_SEARCH_ALL_TEXT_DEFAULT)),
      );
    }
  }
  return system_settings_form($form);
}